@@ -95,10 +95,13 @@ class Map(_FoliumWrapper, collections.abc.Mapping):
         self._width = width
         self._height = height
         self._attrs.update(kwargs)
+        self._set_folium_map()
 
     def copy(self):
         """
         Copies the current Map into a new one and returns it.
+        Note: This only copies rendering attributes. The underlying map is NOT deep-copied.
+        This is as a result of no functionality in Folium. Ref: https://github.com/python-visualization/folium/issues/1207
         """
 
         m = Map(features=self._features, width=self._width,
@@ -360,7 +363,7 @@ class Map(_FoliumWrapper, collections.abc.Mapping):
         result = self.copy()
         if type(feature) == Table:
             # if table of features e.g. Table.from_records(taz_map.features)
-            if 'feature' in feature:
+            if 'feature' in feature.labels:
                 feature = feature['feature']
 
             # if marker table e.g. table with columns: latitudes,longitudes,popup,color,area
@@ -806,6 +809,9 @@ class Circle(Marker):
             attrs['fill_color'] = attrs.pop('color')
         if 'line_color' in attrs:
             attrs['color'] = attrs.pop('line_color')
+        else:
+            if 'fill_color' in attrs:
+                attrs['color'] = attrs['fill_color']
         return attrs
 
     def draw_on(self, folium_map, radius_in_meters=False):
